==> deepin-font-manager_5.8.0.13.orig.tar.xz: deepin-font-manager-5.8.0.13/translations/deepin-font-manager_fi.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fi" version="2.1">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation>Kaikki kirjasimet</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Järjestelmässä</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Käyttäjän</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Suosikit</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Aktiiviset</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>Kiinatuki</translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation>Kiinteävälinen</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Peruuta</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Vahvista</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation>Virheellinen tiedosto</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>Sama versio asennettu</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation>Järjestelmän kirjasin</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation>Ctrl+Shift+/</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Ctrl+Shift+K</source>
        <translation>Ctrl+Shift+K</translation>
    </message>
    <message>
        <source>Alt+Return</source>
        <translation>Alt+Return</translation>
    </message>
    <message>
        <source>Fonts</source>
        <translation>Kirjasimet</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation>%1 kirjasinta asennettu</translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation>%1 kirjasinta asennettu</translation>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>Are you sure you want to delete this font?</source>
        <translation>Haluatko varmasti poistaa tämän kirjasimen?</translation>
    </message>
    <message>
        <source>This font will not be available to applications</source>
        <translation>Tätä kirjasinta ei voi käyttää sovelluksissa</translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation>Nämä kirjasimet eivät ole sovellusten käytettävissä</translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation>Muita %1 järjestelmän kirjasimia ei voi poistaa</translation>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation>Käytössä olevaa kirjasinta &quot;%1&quot; ei voi poistaa</translation>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation>Muita %1 järjestelmän tai käytössä olevaa kirjasinta &quot;%2&quot; ei voi poistaa</translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation>Haluatko varmasti poistaa %1 kirjasinta?</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Poista</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation>Poistetaan kirjasimia, odota...</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation>Kirjasimen varmennus</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Poistu</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Jatka</translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation>Ei asennettavia kirjasimia</translation>
    </message>
</context>
<context>
    <name>Font</name>
    <message>
        <source>Don&apos;t let your dreams be dreams</source>
        <translation>Älä anna unelmiesi olla unelmia</translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Basic info</source>
        <translation>Perustiedot</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Tyyli</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tyyppi</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versio</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Kuvaus</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Tuntematon</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation>Koko nimi</translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation>Jälkikirjoitus</translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation>Tavaramerkki</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation>Kirjasinhallinta</translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>Kirjasinhallinta auttaa käyttäjää asentamaan ja hallitsemaan kirjasimia.</translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation>Ladataan kirjasimia, odota...</translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation>Tämä kirjasin on viety työpöydällesi</translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation>%1 kirjasinta on viety työpöydällesi</translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation>1 kirjasimen vieminen epäonnistui. Levytila ei riitä.</translation>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation>1% kirjasimen vieminen epäonnistui. Levytila ei riitä.</translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation>Lisää kirjasin</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Käytössä</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Estä</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Poista</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Suosikki</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Inhokki</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Tiedot</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Näytä tiedostohallinnassa</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Vie</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>deactivated</source>
        <translation>poistettu</translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation>Nämä kirjasimet on poistettu käytöstä</translation>
    </message>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation>%1 on käytössä, joten et voi poistaa sitä käytöstä</translation>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation>Järjestelmän tai käytössä olevia kirjasimia ei voi poistaa</translation>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation>Järjestelmän kirjasimia ei voi poistaa käytöstä</translation>
    </message>
    <message>
        <source>Some fonts are not allowed to be disabled</source>
        <translation>Jotakin kirjasimia ei voi poistaa käytöstä</translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation>Asenna kirjasin</translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation>Tarkistetaan...</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation>Tuntematon</translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation>Virheellinen tiedosto</translation>
    </message>
    <message>
        <source>Installed</source>
        <translation>Asennetut</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation>Ei asennettu</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation>Asenna kirjasin</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation>Hae</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>Ei hakutuloksia</translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation>Ei kirjasimia</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>Apua</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Näytä kuvakkeet</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Sivu ylös</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Sivu alas</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Poista</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>Lisää kirjasin</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Suosikki</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Inhokki</translation>
    </message>
    <message>
        <source>Font info</source>
        <translation>Kirjasimen tiedot</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation>Esikatselun teksti</translation>
    </message>
</context>
<context>
    <name>DFontWidget</name>
    <message>
        <source>Broken file</source>
        <translation>Virheellinen tiedosto</translation>
    </message>
</context>
</TS>

==> deepin-font-manager_5.9.14.orig.tar.xz: deepin-font-manager-5.9.14/translations/deepin-font-manager_fi.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fi">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation>Kaikki fontit</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Järjestelmässä</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Käyttäjän</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Suosikit</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Aktiiviset</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>Kiinatuki</translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation>Kiinteävälinen</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Peruuta</translation>
    </message>
</context>
<context>
    <name>DFDeleteTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be deleted</source>
        <translation>%1 on fonttiperhe, jos jatkat niin kaikki perheen fontit poistetaan</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Poista</translation>
    </message>
</context>
<context>
    <name>DFDisableTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be enabled</source>
        <translation>%1 on fonttiperhe, jos jatkat niin kaikki perheen fontit otetaan käyttöön</translation>
    </message>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be disabled</source>
        <translation>%1 on fonttiperhe, jos jatkat niin kaikki perheen fontit poistetaan käytöstä</translation>
    </message>
    <message>
        <source>Enable</source>
        <comment>button</comment>
        <translation>Käytössä</translation>
    </message>
    <message>
        <source>Disable</source>
        <comment>button</comment>
        <translation>Estä</translation>
    </message>
</context>
<context>
    <name>DFHandleTTCDialog</name>
    <message>
        <source>Apply to all selected font families</source>
        <translation>Käytä kaikkiin valittuihin fonttiperheisiin</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Peruuta</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation>Virheellinen tiedosto</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>Sama versio asennettu</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation>Järjestelmän fontti</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation>Ctrl+Shift+/</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation>%1 fontti asennettu</translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation>%1 fonttia asennettu</translation>
    </message>
    <message>
        <source>Alt+M</source>
        <translation>Alt+M</translation>
    </message>
    <message>
        <source>CTRL+I</source>
        <translation>CTRL+I</translation>
    </message>
    <message>
        <source>Failed to install %1 font. There is not enough disk space.</source>
        <translation>%1 fontin asennus epäonnistui. Levytila ei riitä.</translation>
    </message>
    <message>
        <source>Failed to install %1 fonts. There is not enough disk space.</source>
        <translation>%1 kirjasimen asentaminen epäonnistui. Levytila ei riitä.</translation>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>This font will not be available to applications</source>
        <translation>Tätä fonttia ei voi käyttää sovelluksissa</translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation>Nämä fontit eivät ole sovellusten käytettävissä</translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation>Muut %1 järjestelmän fonttia ei voi poistaa</translation>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation>Käytössä olevaa fonttia &quot;%1&quot; ei voi poistaa</translation>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation>Muut %1 järjestelmän tai käytössä olevaa fonttia &quot;%2&quot; ei voi poistaa</translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation>Haluatko varmasti poistaa %1 fonttia?</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Poista</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation>Poistetaan fontteja, odota...</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation>Fontin varmennus</translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation>Ei asennettavia fontteja</translation>
    </message>
    <message>
        <source>Exit</source>
        <comment>button</comment>
        <translation>Poistu</translation>
    </message>
    <message>
        <source>Continue</source>
        <comment>button</comment>
        <translation>Jatka</translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Basic info</source>
        <translation>Perustiedot</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Tyyli</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tyyppi</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versio</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Kuvaus</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Tuntematon</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation>Koko nimi</translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation>Jälkikirjoitus</translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation>Tavaramerkki</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation>Fontit</translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>Fontit auttaa hallitsemaan ja asentamaan fontteja.</translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation>Ladataan fontteja, odota...</translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation>Tämä fontti on viety työpöydällesi</translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation>%1 fontit on viety työpöydällesi</translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation>1 fontin vieminen epäonnistui. Levytila ei riitä.</translation>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation>1% fontin vieminen epäonnistui. Levytila ei riitä.</translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation>Lisää fontti</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Käytössä</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Estä</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Poista</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Suosikki</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Inhokki</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Tiedot</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Näytä tiedostohallinnassa</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Vie</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>deactivated</source>
        <translation>poistettu</translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation>Nämä fonttit on poistettu käytöstä</translation>
    </message>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation>%1 on käytössä, joten et voi poistaa sitä käytöstä</translation>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation>Käytössä olevaa tai järjestelmän fonttia ei voi poistaa</translation>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation>Fontteja ei voi poistaa järjestelmän käytöstä</translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation>Asenna fontti</translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation>Tarkistetaan...</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation>Tuntematon</translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation>Virheellinen tiedosto</translation>
    </message>
    <message>
        <source>Installed</source>
        <translation>Asennetut</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation>Ei asennettu</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation>Asenna fontti</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation>Hae</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>Ei hakutuloksia</translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation>Ei fontteja</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>Apua</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Näytä kuvakkeet</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Sivu ylös</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Sivu alas</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Poista</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>Lisää fontti</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Suosikki</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Inhokki</translation>
    </message>
    <message>
        <source>Font info</source>
        <translation>Tiedot fontista</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation>Esikatselun teksti</translation>
    </message>
</context>
</TS>
